/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'image', 'bn', {
	alt: 'বিকল্প টেক্সট',
	border: 'বর্ডার',
	btnUpload: 'ইহাকে সার্ভারে প্রেরন কর',
	button2Img: 'Do you want to transform the selected image button on a simple image?', // MISSING
	hSpace: 'হরাইজন্টাল স্পেস',
	img2Button: 'Do you want to transform the selected image on a image button?', // MISSING
	infoTab: 'ছবির তথ্য',
	linkTab: 'লিংক',
	lockRatio: 'অনুপাত লক কর',
	menu: 'ছবির প্রোপার্টি',
	resetSize: 'সাইজ পূর্বাবস্থায় ফিরিয়ে দাও',
	title: 'ছবির প্রোপার্টি',
	titleButton: 'ছবির বাটন সম্বন্ধীয়',
	upload: 'আপলোড',
	urlMissing: 'Image source URL is missing.', // MISSING
	vSpace: 'ভার্টিকেল স্পেস',
	validateBorder: 'Border must be a whole number.', // MISSING
	validateHSpace: 'HSpace must be a whole number.', // MISSING
	validateVSpace: 'VSpace must be a whole number.' // MISSING
} );
